<template>
  <div>
    <div class="search">
      <van-dropdown-menu class="dropdown">
        <van-dropdown-item v-model="querys[0].value" :options="options" style="width: 30%;" @change="onSearch" />
      </van-dropdown-menu>
      <van-dropdown-menu class="dropdown">
        <van-dropdown-item v-model="querys[1].value" :options="caseNodeLsit" style="width: 30%;"    
                           @change="onSearch" />
      </van-dropdown-menu>
      <van-search style="width:65%" v-model="querys[2].value" placeholder="请输入案件编码" @blur="onSearch" />
    </div>
    <van-list style="padding-top: 4rem;box-sizing: border-box;" v-model="loading" :finished="finished"
              finished-text="没有更多了" @load="onLoad">
      <div class="table-item" v-for="(item, index) in list" :key="index" @click="toDetail(item)">
        <div class="title">
          <div>
            <div :class="item.caseUrgency === '1'
                            ? 'pain-primary-tag'
                            : item.caseUrgency === '2'
                                ? 'pain-danger-tag'
                                : ''
                            ">
              {{
                item.caseUrgency === '1'
                  ? '普通'
                  : item.caseUrgency === '2'
                    ? '紧急'
                    : ''
              }}
            </div>
            {{ item.caseCode }}
          </div>
          <div class="tag">
            {{ getDictName('tybagl-ajlx', item.caseType) }}
          </div>
        </div>
        <div style="display: flex;justify-content: space-between;">
          <div class="two-title">
            案件类型：{{ getDictName('tybagl-ajyxhj', item.caseNode) }}
          </div>
          <div class="two-title">
            案件性质：{{ getDictName('tybagl-ajxz', item.caseNature) }}
          </div>
        </div>
        <div class="two-title">
          当事人单位：{{ getDictName('tybagl-dsrlx', item.objectType) }}
        </div>
        <div class="two-title">案由：{{ item.caseReason }}</div>
        <div class="two-title">案发地址：{{ item.caseAddr }}</div>
        <div class="urgency-settings">
          <div class="two-title">创建时间：{{ item.createTime }}</div>
          <div class="btn" @click.stop="settingsBtn(item)">急要件设置</div>
        </div>
      </div>
    </van-list>
  </div>
</template>
<script>
import api from '@/api/device/caseExamine.js'
import utils from '@/utils.js'
import {Dialog} from 'vant'
import dictUtils from '@/components/dict/DictSelectUtils'

export default {
  name: 'GeneralCases',
  data() {
    return {
      loginname: '',
      value: '',
      value1: '',
      options: [],
      list: [],
      loading: false,
      finished: false,
      total: 0,
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'caseType',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'caseNode',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'caseCode',
          relation: 'AND',
          value: ''
        }
      ],
      queryParam: {
        pageBean: {
          pageSize: 0,
          page: 1
        },
        params: {},
        querys: []
      }
    }
  },
  created() {
    this.options = dictUtils.getDictItemsFromCache('tybagl-ajlx').map(item => {
      return {
        text: item.name,
        value: item.value
      }
    })
    this.options.unshift({
      text: '全部类型',
      value: ''
    })
    this.caseNodeLsit = dictUtils.getDictItemsFromCache('tybagl-ajyxhj').map(item => {
      return {
        text: item.name,
        value: item.value
      }
    })
    this.caseNodeLsit.unshift({
      text: '全部阶段',
      value: ''
    })
  },
  mounted() {
  },
  methods: {
    //急要件设置
    settingsBtn(item) {
      Dialog.confirm({
        message: '是否设置为急要件'
      })
        .then(() => {
          api.urgencySetting(item.id, res => {
            if (res.state) {
              this.$toast.success('设置成功')
              this.getData()
            }
          })
        })
        .catch(() => {
          // on cancel
        })
    },
    //字典翻译
    getDictName(code, value) {
      let name
      dictUtils.getDictItemsFromCache(code).forEach(e => {
        if (e.value == value) {
          name = e.name
        }
      })
      return name
    },
    onLoad() {
      this.queryParam.pageBean.pageSize += 10
      this.getData()
    },
    onSearch() {
      this.queryParam.pageBean.pageSize = 10
      this.finished = false
      this.getData()
    },
    getData() {
      this.loading = false
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      api.queryData(this.queryParam, res => {
        if (res.rows) {
          this.list = res.rows
          this.total = res.total
          if (this.list.length >= this.total) {
            this.finished = true
          }
        } else {
          this.finished = true
        }
      })
    },
    toDetail(val) {
      this.$router.push({name: 'caseExamineDetails', query: {id: val.id}})
    }
  }
}
</script>
<style scoped lang="scss">
.search {
  width: 100%;
  position: fixed;
  display: flex;
  background-color: #fff;
  justify-content: space-between;
  top: 86PX;
  box-shadow: 0 2px 12px rgba(100, 101, 102, 0.12);

  .dropdown {
    box-shadow: none;
    width: 30%;
  }
}

.table-item {
  background: #fff;
  box-shadow: 0 0 0.5rem 0.2rem rgba(82, 81, 81, 0.11);
  border-radius: 1rem;
  margin: 1rem 0.7rem;
  padding: 1rem;
  box-sizing: border-box;

  .title {
    display: flex;
    justify-content: space-between;
    padding: 0.8rem 0;

    div:nth-child(1) {
      font-weight: bold;
    }
  }

  .two-title {
    color: #7e7d7d;
    line-height: 2rem;
  }

  .urgency-settings {
    display: flex;
    justify-content: space-between;

    .btn {
      display: flex;
      justify-content: center;
      align-items: center;
      width: 400px;
      color: #1a89fa;
      border-radius: 100px;
      background-color: #fff;
      border: 1px solid #1a89fa;
    }
  }
}

.tag {
  display: inline-block;
  background-color: #1a89fa;
  padding: 0.1rem 0.4rem;
  border-radius: 0.4rem;
  box-sizing: border-box;
  color: #fff;
}

.pain-primary-tag {
  display: inline-block;
  background-color: #fff;
  padding: 0.1rem 0.4rem;
  border-radius: 0.4rem;
  box-sizing: border-box;
  border: 1px solid #1a89fa;
  color: #1a89fa;
}

.pain-danger-tag {
  display: inline-block;
  background-color: #fff;
  padding: 0.1rem 0.4rem;
  border-radius: 0.4rem;
  box-sizing: border-box;
  border: 1px solid #ee0b24;
  color: #ee0b24;
}

::v-deep .van-search {
  padding: 0;
}

::v-deep .van-dropdown-menu__bar {
  box-shadow: none;
}
</style>
